%{?scl:%scl_package lldb}
%{!?scl:%global pkg_name %{name}}
%global devtoolset_name devtoolset-9

#%%global rc_ver 6
%global baserelease 1

%global _smp_mflags -j4

%global lldb_srcdir lldb-%{version}%{?rc_ver:rc%{rc_ver}}.src

Name:		%{?scl_prefix}lldb
Version:	13.0.1%{?rc_ver:~rc%{rc_ver}}
Release:	%{baserelease}%{?rc_ver:.rc%{rc_ver}}%{?dist}
Summary:	Next generation high-performance debugger

License:	NCSA
URL:		http://lldb.llvm.org/
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{lldb_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{lldb_srcdir}.tar.xz.sig
Source2:	tstellar-gpg-key.asc

Patch0:     0001-Remove-SVE-support.patch
Patch1:     0002-Bundle-swig-generated-sources-to-avoid-swig-dependen.patch

BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	%{?scl_prefix}cmake
BuildRequires:	%{?scl_prefix}llvm-devel = %{version}
BuildRequires:	%{?scl_prefix}llvm-test = %{version}
BuildRequires:	%{?scl_prefix}clang-devel = %{version}
BuildRequires:	ncurses-devel
BuildRequires:	%{?scl_prefix}llvm-static = %{version}
BuildRequires:	libffi-devel
BuildRequires:	zlib-devel
BuildRequires:	libxml2-devel
BuildRequires:	libedit-devel
BuildRequires:	%{?scl_prefix}python-lit
BuildRequires:	multilib-rpm-config
# for py_byte_compile
BuildRequires: python3-devel

Requires: %{?scl_prefix}python3-lldb

%description
LLDB is a next generation, high-performance debugger. It is built as a set
of reusable components which highly leverage existing libraries in the
larger LLVM Project, such as the Clang expression parser and LLVM
disassembler.

%package -n %{?scl_prefix}devel
Summary:	Development header files for LLDB
Requires:	%{?scl_prefix}%{pkg_name}%{?_isa} = %{version}-%{release}

%description -n %{?scl_prefix}devel
The package contains header files for the LLDB debugger.

%package -n %{?scl_prefix}python3-lldb
Summary:	Python module for LLDB
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
Requires:	%{?scl_prefix}%{pkg_name}%{?_isa} = %{version}-%{release}
Provides:   bundled(python3dist(six))

%description -n %{?scl_prefix}python3-lldb
The package contains the LLDB Python module.

# LLVM libraries and tools no longer set rpath, so we need to enable the scl
# so llvm-config can find libLLVM.so.
%enable_llvmtoolset11_0

%prep
%autosetup -n %{lldb_srcdir} -p2

%build

mkdir -p _build
cd _build

CFLAGS="%{optflags} -Wno-error=format-security"
CXXFLAGS="%{optflags} -Wno-error=format-security"

%cmake .. \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
    -DCMAKE_C_COMPILER=/opt/rh/%{devtoolset_name}/root/usr/bin/gcc\
    -DCMAKE_CXX_COMPILER=/opt/rh/%{devtoolset_name}/root/usr/bin/g++\
	-DLLVM_CONFIG:FILEPATH=/usr/bin/llvm-config-%{__isa_bits} \
	\
	-DLLDB_DISABLE_CURSES:BOOL=OFF \
%ifarch ppc64 s390x
	-DLLDB_DISABLE_LIBEDIT:BOOL=ON \
%else
	-DLLDB_DISABLE_LIBEDIT:BOOL=OFF \
%endif
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
	\
	-DPYTHON_EXECUTABLE:STRING=%{__python3} \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DLLDB_USE_SYSTEM_SIX=OFF \
    -DLLDB_ENABLE_PYTHON=ON \
	-DCLANG_LINK_CLANG_DYLIB=ON \
	-DLLVM_LIT_ARGS="-sv \
	--path %{_libdir}/llvm" \
	-DHAVE_LIBPTHREAD=ON

cp ../bindings/python/LLDBWrapPython.cpp bindings/python/
cp ../bindings/python/lldb.py bindings/python/
make %{?_smp_mflags}

%install
cd _build
make install DESTDIR=%{buildroot}

%multilib_fix_c_header --file %{_includedir}/lldb/Host/Config.h

# remove static libraries
rm -fv %{buildroot}%{_libdir}/*.a

# python: fix binary libraries location
mkdir -p %{buildroot}%{?scl:%{_scl_root}}%{python3_sitearch}/lldb
liblldb=$(basename $(readlink -e %{buildroot}%{_libdir}/liblldb.so))
ln -vsf "../../../${liblldb}" %{buildroot}%{?scl:%{_scl_root}}%{python3_sitearch}/lldb/_lldb.so

# install bundled six in an lldb-private location
mv %{buildroot}%{?scl:%{_scl_root}}%{python3_sitearch}/six.py %{buildroot}%{?scl:%{_scl_root}}%{python3_sitearch}/lldb/
find %{buildroot}%{?scl:%{_scl_root}}%{python3_sitearch}/lldb -name '*.py' -exec sed -i -e 's/import six/import lldb.six as six/' {} \;

%py_byte_compile %{__python3} %{buildroot}%{?scl:%{_scl_root}}%{python3_sitearch}/lldb

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license LICENSE.TXT
%{_bindir}/lldb*
%{_libdir}/liblldb.so.*
%{_libdir}/liblldbIntelFeatures.so.*

%files -n %{?scl_prefix}devel
%{_includedir}/lldb
%{_libdir}/*.so

%files -n %{?scl_prefix}python3-lldb
%{?scl:%{_scl_root}}%{python3_sitearch}/lldb

%changelog
* Thu Feb 03 2022 Tom Stellard <tstellar@redhat.com> - 13.0.1-1
- 13.0.1 Release

* Wed Nov 3 2021 sguelton@redhat.com - 13.0.0-1
- LLVM 13.0.0

* Wed Aug 18 2021 sguelton@redhat.com - 12.0.1-3
- Fix scl prefix for python3-lldb

* Mon Aug 16 2021 sguelton@redhat.com - 12.0.1-2
- Bundle swig-generated file to drop swig dependency
- Use bundled version of six

* Tue Jul 20 2021 sguelton@redhat.com - 12.0.1-1
- LLVM 12.0.1

* Tue Jul 06 2021 sguelton@redhat.com - 12.0.0-1
- llvm 12.0.0

* Mon Jan 25 2021 sguelton@redhat.com - 11.0.1-1
- 11.0.1 Release

* Wed Jul 22 2020 <sguelton@redhat.com> - 10.0.1-1
- 10.0.1 Release

* Thu Jul 16 2020 sguelton@redhat.com - 10.0.0-1
- 10.0.0

* Mon Mar 30 2020 Tom Stellard <tstellar@redhat.com> - 9.0.1-5
- Disable ppc64 builds

* Mon Mar 23 2020 Tom Stellard <tstellar@redhat.com> - 9.0.1-4
- Fix ppc64 big-endian detection

* Mon Mar 23 2020 Tom Stellard <tstellar@redhat.com> - 9.0.1-3
- Also disable libedit on s390x

* Fri Mar 20 2020 Tom Stellard <tstellar@redhat.com> - 9.0.1-2
- Disable libedit on ppc64
- rhbz#1814857

* Tue Jan 28 2020 Tom Stellard <tstellar@redhat.com> - 9.0.1-1
- 9.0.1 Release

* Wed Aug 28 2019 sguelton@redhat.com - 8.0.1-3
- Remove __cmake hack

* Wed Aug 21 2019 sguelton@redhat.com - 8.0.1-2
- Remove ExclusiveArch, rhbz#1610810, rhbz#1610800

* Thu Aug 1 2019 sguelton@redhat.com - 8.0.1-1
- 8.0.1 Release

* Thu Jan 10 2019 Tom Stellard <tstellar@redhat.com> - 7.0.1-1
- 7.0.1 Release

* Mon May 21 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-1
- 6.0.1 Release

* Wed Mar 14 2018 Tilmann Scheller <tschelle@redhat.com> - 5.0.1-4
- Backport test fixes for rhbz#1470621, fixes various tests that are timing out

* Wed Mar 14 2018 Tilmann Scheller <tschelle@redhat.com> - 5.0.1-3
- Backport test fixes for rhbz#1470608, fixes TestLambdas.py

* Tue Jan 16 2018 Tom Stellard <tstellar@redhat.com> - 5.0.1-2
- Rebuid for i686

* Thu Jan 11 2018 Tom Stellard <tstellar@redhat.com> - 5.0.1-1
- 5.0.1 Release

* Wed Aug 16 2017 Tom Stellard <tstellar@redhat.com> - 4.0.1-4
-  Fix crash when loading Fedora debuginfo
   Resloves: #1479529

* Mon Jul 31 2017 Jan Kratochvil <jan.kratochvil@redhat.com> - 4.0.1-3
- Backport lldb r303907
  Resolves: #1356140

* Thu Jun 22 2017 Tom Stellard <tstellar@redhat.com> - 4.0.1-2
- Fix requires for python-lldb

* Wed Jun 21 2017 Tom Stellard <tstellar@redhat.com> - 4.0.1-1
- Build for llvm-toolset-7 rename

* Wed Jun 07 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-3
- Build for llvm-toolset-7 rename

* Thu May 18 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-2
- Fix Requires

* Fri Mar 24 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-1
- lldb 4.0.0

* Tue Mar 21 2017 Tom Stellard <tstellar@redhat.com> - 3.9.1-4
- Add explicit Requires for llvm-libs and clang-libs

* Fri Mar 17 2017 Tom Stellard <tstellar@redhat.org> - 3.9.1-3
- Adjust python sys.path so lldb can find readline.so

* Tue Mar 14 2017 Tom Stellard <tstellar@redhat.com> - 3.9.1-2
- Fix build with gcc 7

* Thu Mar 02 2017 Dave Airlie <airlied@redhat.com - 3.9.1-1
- lldb 3.9.1

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.9.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Nov 14 2016 Nathaniel McCallum <npmccallum@redhat.com> - 3.9.0-3
- Disable libedit support until upstream fixes it (#1356140)

* Wed Nov  2 2016 Peter Robinson <pbrobinson@fedoraproject.org> 3.9.0-2
- Set upstream supported architectures in an ExclusiveArch

* Wed Oct 26 2016 Dave Airlie <airlied@redhat.com> - 3.9.0-1
- lldb 3.9.0
- fixup some issues with MIUtilParse by removing it
- build with -fno-rtti

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Mar 10 2016 Dave Airlie <airlied@redhat.com> 3.8.0-1
- lldb 3.8.0

* Thu Mar 03 2016 Dave Airlie <airlied@redhat.com> 3.8.0-0.3
- lldb 3.8.0 rc3

* Wed Feb 24 2016 Dave Airlie <airlied@redhat.com> - 3.8.0-0.2
- dynamically link to llvm

* Thu Feb 18 2016 Dave Airlie <airlied@redhat.com> - 3.8.0-0.1
- lldb 3.8.0 rc2

* Sun Feb 14 2016 Dave Airlie <airlied@redhat.com> 3.7.1-3
- rebuild lldb against latest llvm

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Oct 06 2015 Jan Vcelak <jvcelak@fedoraproject.org> 3.7.0-100
- initial version using cmake build system
